=== added directory 'pay-test-app'
=== added file 'pay-test-app/CMakeLists.txt'
--- pay-test-app/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ pay-test-app/CMakeLists.txt	2014-08-05 23:30:20 +0000
@@ -0,0 +1,36 @@
+project(pay-test-app)
+cmake_minimum_required(VERSION 2.8)
+
+set(CMAKE_INCLUDE_CURRENT_DIR ON)
+set(CMAKE_AUTOMOC ON)
+set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -std=c++11 -g -Wall -Werror")
+
+include(GNUInstallDirs)
+
+# Workaround for libexecdir on debian
+if (EXISTS "/etc/debian_version") 
+	set(CMAKE_INSTALL_LIBEXECDIR ${CMAKE_INSTALL_LIBDIR})
+	set(CMAKE_INSTALL_FULL_LIBEXECDIR "${CMAKE_INSTALL_PREFIX}/${CMAKE_INSTALL_LIBEXECDIR}")
+endif()
+
+set(pkglibexecdir "${CMAKE_INSTALL_FULL_LIBEXECDIR}/${CMAKE_PROJECT_NAME}")
+
+find_package(Qt5Core)
+find_package(Qt5Qml)
+find_package(Qt5Quick)
+find_package(PkgConfig)
+
+pkg_check_modules(PAY REQUIRED pay-2)
+include_directories (SYSTEM ${PAY_INCLUDE_DIRS})
+
+add_executable(pay-test-app pay-test-app.cpp package.h package.cpp qtquick2applicationviewer.cpp qtquick2applicationviewer.h)
+qt5_use_modules(pay-test-app Core Qml Quick)
+target_link_libraries(pay-test-app ${PAY_LIBRARIES})
+install(TARGETS pay-test-app RUNTIME DESTINATION ${pkglibexecdir})
+
+install(FILES pay-test-app.qml DESTINATION ${pkglibexecdir})
+install(FILES pay-test-app.svg DESTINATION "${CMAKE_INSTALL_DATADIR}/icons/hicolor/scalable/apps/")
+
+configure_file("pay-test-app.desktop.in" "${CMAKE_CURRENT_BINARY_DIR}/pay-test-app.desktop" @ONLY)
+install(FILES "${CMAKE_CURRENT_BINARY_DIR}/pay-test-app.desktop"
+	DESTINATION "${CMAKE_INSTALL_DATADIR}/applications/")

=== added file 'pay-test-app/package.cpp'
--- pay-test-app/package.cpp	1970-01-01 00:00:00 +0000
+++ pay-test-app/package.cpp	2014-08-05 23:30:20 +0000
@@ -0,0 +1,105 @@
+#include "package.h"
+#include <QDebug>
+
+static QString enum2str (PayPackageItemStatus val);
+
+Package::Package (QObject * parent):
+	QObject(parent)
+{
+	return;
+}
+
+QString Package::pkgname (void) const
+{
+	return _pkgname;
+}
+
+static void itemObserver (PayPackage * pkg, const char * itemid, PayPackageItemStatus status, void * user_data)
+{
+	Package * notthis = reinterpret_cast<Package *>(user_data);
+	QString item(itemid);
+	notthis->emitItemChanged(item, enum2str(status));
+}
+
+void Package::emitItemChanged (const QString &item, const QString &status)
+{
+	emit itemStatusChanged(item, status);
+}
+
+void Package::setPkgname (const QString &pkgname)
+{
+	if (pkgname == _pkgname) {
+		return;
+	}
+
+	_pkgname = pkgname;
+	pkg = std::shared_ptr<PayPackage>([this]() -> PayPackage * {
+		PayPackage * pkg = pay_package_new(_pkgname.toUtf8().data());
+
+		if (pkg != nullptr) {
+			pay_package_item_observer_install(pkg, itemObserver, this);
+		}
+
+		return pkg;
+	}(),
+	[this](PayPackage * pkg) {
+		if (pkg != nullptr) {
+			pay_package_item_observer_uninstall(pkg, itemObserver, this);
+			pay_package_delete(pkg);
+		}});
+
+	qDebug() << "Pay Package built for:" << _pkgname.toUtf8().data();
+
+	pkgnameChanged();
+}
+
+static QString enum2str (PayPackageItemStatus val)
+{
+	switch (val) {
+	case PAY_PACKAGE_ITEM_STATUS_VERIFYING:
+		return QString("Verifying");
+	case PAY_PACKAGE_ITEM_STATUS_PURCHASED:
+		return QString("Purchased");
+	case PAY_PACKAGE_ITEM_STATUS_PURCHASING:
+		return QString("Purchasing");
+	case PAY_PACKAGE_ITEM_STATUS_NOT_PURCHASED:
+		return QString("Not Purchased");
+	case PAY_PACKAGE_ITEM_STATUS_UNKNOWN:
+		break;
+	}
+
+	return QString("Unknown");
+}
+
+QString Package::itemStatus (const QString &item)
+{
+	QString retval;
+
+	if (pkg == nullptr) {
+		return retval;
+	}
+
+	return enum2str(pay_package_item_status(pkg.get(), item.toUtf8().data()));
+}
+
+bool Package::verifyItem (const QString & item)
+{
+	if (pkg == nullptr)
+		return false;
+
+	qDebug() << "Verifying item" << item << "for package" << _pkgname;
+
+	return pay_package_item_start_verification(pkg.get(), item.toUtf8().data());
+}
+
+bool Package::purchaseItem (const QString & item)
+{
+	if (pkg == nullptr)
+		return false;
+
+	qDebug() << "Purchasing item" << item << "for package" << _pkgname;
+
+	return pay_package_item_start_purchase(pkg.get(), item.toUtf8().data());
+}
+
+#include "moc_package.cpp"

=== added file 'pay-test-app/package.h'
--- pay-test-app/package.h	1970-01-01 00:00:00 +0000
+++ pay-test-app/package.h	2014-08-05 23:30:20 +0000
@@ -0,0 +1,39 @@
+
+#ifndef PACKAGE_H
+#define PACKAGE_H 1
+
+#include <memory>
+
+#include <QObject>
+
+#include <libpay/pay-package.h>
+
+class Package : public QObject
+{
+	Q_OBJECT
+
+	Q_PROPERTY(QString pkgname READ pkgname WRITE setPkgname NOTIFY pkgnameChanged)
+
+public:
+	QString pkgname() const;
+	void setPkgname(const QString &pkgname);
+
+	Package (QObject * parent = nullptr);
+
+	Q_INVOKABLE QString itemStatus (const QString & item);
+	Q_INVOKABLE bool verifyItem (const QString & item);
+	Q_INVOKABLE bool purchaseItem (const QString & item);
+
+signals:
+	void pkgnameChanged();
+	void itemStatusChanged(const QString &item, const QString& status);
+
+private:
+	std::shared_ptr<PayPackage> pkg;
+	QString _pkgname;
+
+public:
+	void emitItemChanged(const QString& item, const QString& status);
+};
+
+#endif /* PACKAGE_H */

=== added file 'pay-test-app/pay-test-app.cpp'
--- pay-test-app/pay-test-app.cpp	1970-01-01 00:00:00 +0000
+++ pay-test-app/pay-test-app.cpp	2014-08-05 23:30:20 +0000
@@ -0,0 +1,20 @@
+
+#include <QQuickView>
+#include <QtGui/QGuiApplication>
+#include <QtQml/qqml.h>
+
+#include "qtquick2applicationviewer.h"
+#include "package.h"
+
+int main (int argc, char * argv[])
+{
+	QGuiApplication app(argc, argv);
+
+	qmlRegisterType<Package>("Pay", 1, 0, "Package");
+
+	QtQuick2ApplicationViewer view;
+	view.setMainQmlFile(QStringLiteral("pay-test-app.qml"));
+	view.showExpanded();
+
+	return app.exec();
+}

=== added file 'pay-test-app/pay-test-app.desktop.in'
--- pay-test-app/pay-test-app.desktop.in	1970-01-01 00:00:00 +0000
+++ pay-test-app/pay-test-app.desktop.in	2014-08-05 23:30:20 +0000
@@ -0,0 +1,9 @@
+[Desktop Entry]
+Name=Pay Test App
+Comment=Used for testing pay service, nothing else
+Exec=@pkglibexecdir@/pay-test-app
+Path=@pkglibexecdir@
+Type=Application
+Icon=pay-test-app
+X-Ubuntu-Single-Instance=true
+X-Ubuntu-Touch=true

=== added file 'pay-test-app/pay-test-app.qml'
--- pay-test-app/pay-test-app.qml	1970-01-01 00:00:00 +0000
+++ pay-test-app/pay-test-app.qml	2014-08-05 23:30:20 +0000
@@ -0,0 +1,81 @@
+import QtQuick 2.0
+import Ubuntu.Components 1.1
+import Ubuntu.Components.ListItems 1.0 as ListItem
+import Pay 1.0
+
+MainView {
+	id: mainview
+	automaticOrientation: true
+
+	Package {
+		id: pkg
+		pkgname: "pay-test-app"
+
+		onItemStatusChanged: {
+			statusBox.text = pkg.itemStatus(idBox.text)
+		}
+	}
+
+	Page {
+		title: i18n.tr("Pay Test")
+
+		Column {
+
+			width: parent.width
+			height: parent.height
+
+			ListItem.SingleControl {
+				control: TextField {
+					id: idBox
+					x: units.gu(1)
+					y: units.gu(1)
+					width: parent.width - units.gu(2)
+					text: i18n.tr("Item ID")
+
+					onTextChanged: {
+						statusBox.text = pkg.itemStatus(idBox.text)
+					}
+				}
+			}
+			ListItem.Divider {
+			}
+			ListItem.SingleControl {
+				control: TextField {
+					id: statusBox
+					x: units.gu(1)
+					y: units.gu(1)
+					width: parent.width - units.gu(2)
+					text: i18n.tr("Unknown")
+					readOnly: true
+					hasClearButton: false
+				}
+			}
+			ListItem.Divider {
+			}
+			ListItem.SingleControl {
+				control: Button {
+					x: units.gu(1)
+					y: units.gu(1)
+					width: parent.width - units.gu(2)
+					text: i18n.tr("Verify")
+					onClicked: {
+						pkg.verifyItem(idBox.text)
+						return false
+					}
+				}
+			}
+			ListItem.SingleControl {
+				control: Button {
+					x: units.gu(1)
+					y: units.gu(1)
+					width: parent.width - units.gu(2)
+					text: i18n.tr("Purchase")
+					onClicked: {
+						pkg.purchaseItem(idBox.text)
+						return false
+					}
+				}
+			}
+		}
+	}
+}

=== added file 'pay-test-app/pay-test-app.svg'
--- pay-test-app/pay-test-app.svg	1970-01-01 00:00:00 +0000
+++ pay-test-app/pay-test-app.svg	2014-08-05 23:30:20 +0000
@@ -0,0 +1,122 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="256"
+   height="256"
+   id="svg2"
+   version="1.1"
+   inkscape:version="0.48.4 r9939"
+   sodipodi:docname="pay-test-app.svg">
+  <defs
+     id="defs4">
+    <clipPath
+       id="clipPath18"
+       clipPathUnits="userSpaceOnUse">
+      <path
+         id="path20"
+         d="M 0,2743.88 0,0 l 2743.81,0 0,2743.88 -2743.81,0 z"
+         inkscape:connector-curvature="0" />
+    </clipPath>
+    <clipPath
+       id="clipPath40"
+       clipPathUnits="userSpaceOnUse">
+      <path
+         id="path42"
+         d="M 0,500 1024,500 1024,0 0,0 0,500 Z"
+         inkscape:connector-curvature="0" />
+    </clipPath>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="1"
+     inkscape:pageshadow="2"
+     inkscape:zoom="3.5078125"
+     inkscape:cx="69.416481"
+     inkscape:cy="128"
+     inkscape:document-units="px"
+     inkscape:current-layer="g2846"
+     showgrid="false"
+     inkscape:showpageshadow="false"
+     inkscape:window-width="1920"
+     inkscape:window-height="1056"
+     inkscape:window-x="0"
+     inkscape:window-y="24"
+     inkscape:window-maximized="1" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title></dc:title>
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer"
+     id="layer1"
+     transform="translate(0,-796.36218)">
+    <g
+       transform="matrix(2.3275333,0,0,-2.3275333,22.502226,1029.8588)"
+       id="g2846">
+      <path
+         d="M 90.652,45.325 C 90.652,20.293 70.359,0 45.326,0 20.293,0 0,20.293 0,45.325 c 0,25.033 20.293,45.326 45.326,45.326 25.033,0 45.326,-20.293 45.326,-45.326"
+         style="fill:#e13f20"
+         id="path24"
+         inkscape:connector-curvature="0" />
+      <path
+         d="m 45.326,27.648 c -2.6602,0 -5.1836,0.5918 -7.4453,1.6446 l -4.2051,-7.5352 c 3.5117,-1.7402 7.4668,-2.7226 11.65,-2.7226 2.4336,0 4.7871,0.3378 7.0234,0.957 0.3945,2.4316 1.8379,4.6699 4.1387,6 2.2988,1.3262 4.9551,1.457 7.2558,0.5879 4.4747,4.4004 7.3868,10.385 7.8106,17.051 l -8.625,0.1269 c -0.793,-9.031 -8.37,-16.11 -17.604,-16.11 z m 0,35.354 c 9.2343,0 16.81,-7.08 17.605,-16.109 l 8.6231,0.1269 c -0.4238,6.666 -3.3359,12.65 -7.8106,17.051 -2.3007,-0.8691 -4.9589,-0.7363 -7.2558,0.5879 -2.3008,1.3281 -3.7442,3.5684 -4.1387,6 -2.2363,0.6172 -4.5898,0.9551 -7.0234,0.9551 -4.1836,0 -8.1387,-0.9825 -11.65,-2.7207 l 4.2051,-7.5352 c 2.2617,1.0527 4.7851,1.6445 7.4453,1.6445 z M 27.65,45.325 c 0,5.9805 2.9707,11.264 7.5156,14.463 l -4.4238,7.4102 c -5.2949,-3.5391 -9.2344,-8.9473 -10.871,-15.281 1.9101,-1.5586 3.1328,-3.9316 3.1328,-6.5918 0,-2.6586 -1.2227,-5.0316 -3.1328,-6.5902 1.6348,-6.336 5.5742,-11.744 10.871,-15.283 l 4.4238,7.4121 C 30.6207,34.0615 27.65,39.3448 27.65,45.3253 z"
+         style="fill:#ffffff"
+         id="path26"
+         inkscape:connector-curvature="0"
+         sodipodi:nodetypes="cccscccccccccccccsccccccccsccccc" />
+    </g>
+    <text
+       xml:space="preserve"
+       style="font-size:40px;font-style:normal;font-variant:normal;font-weight:500;font-stretch:normal;line-height:125%;letter-spacing:0px;word-spacing:0px;fill:#ffffff;fill-opacity:1;stroke:none;font-family:Ubuntu;-inkscape-font-specification:Ubuntu Medium"
+       x="151.66147"
+       y="875.0437"
+       id="text3170"
+       sodipodi:linespacing="125%"><tspan
+         sodipodi:role="line"
+         id="tspan3172"
+         x="151.66147"
+         y="875.0437">£</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:40px;font-style:normal;font-variant:normal;font-weight:500;font-stretch:normal;line-height:125%;letter-spacing:0px;word-spacing:0px;fill:#ffffff;fill-opacity:1;stroke:none;font-family:Ubuntu;-inkscape-font-specification:Ubuntu Medium"
+       x="152.51984"
+       y="1002.3396"
+       id="text3170-1"
+       sodipodi:linespacing="125%"><tspan
+         sodipodi:role="line"
+         id="tspan3172-6"
+         x="152.51984"
+         y="1002.3396">¥</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:40px;font-style:normal;font-variant:normal;font-weight:500;font-stretch:normal;line-height:125%;letter-spacing:0px;word-spacing:0px;fill:#ffffff;fill-opacity:1;stroke:none;font-family:Ubuntu;-inkscape-font-specification:Ubuntu Medium"
+       x="43.905128"
+       y="937.62695"
+       id="text3170-5"
+       sodipodi:linespacing="125%"><tspan
+         sodipodi:role="line"
+         id="tspan3172-2"
+         x="43.905128"
+         y="937.62695">$</tspan></text>
+  </g>
+</svg>

=== added file 'pay-test-app/qtquick2applicationviewer.cpp'
--- pay-test-app/qtquick2applicationviewer.cpp	1970-01-01 00:00:00 +0000
+++ pay-test-app/qtquick2applicationviewer.cpp	2014-08-05 23:30:20 +0000
@@ -0,0 +1,81 @@
+// checksum 0x4f6f version 0x90005
+/*
+  This file was generated by the Qt Quick 2 Application wizard of Qt Creator.
+  QtQuick2ApplicationViewer is a convenience class containing mobile device specific
+  code such as screen orientation handling. Also QML paths and debugging are
+  handled here.
+  It is recommended not to modify this file, since newer versions of Qt Creator
+  may offer an updated version of it.
+*/
+
+#include "qtquick2applicationviewer.h"
+
+#include <QtCore/QCoreApplication>
+#include <QtCore/QDir>
+#include <QtQml/QQmlEngine>
+
+class QtQuick2ApplicationViewerPrivate
+{
+    QString mainQmlFile;
+    friend class QtQuick2ApplicationViewer;
+    static QString adjustPath(const QString &path);
+};
+
+QString QtQuick2ApplicationViewerPrivate::adjustPath(const QString &path)
+{
+#if defined(Q_OS_MAC)
+    if (!QDir::isAbsolutePath(path))
+        return QString::fromLatin1("%1/../Resources/%2")
+                .arg(QCoreApplication::applicationDirPath(), path);
+#elif defined(Q_OS_BLACKBERRY)
+    if (!QDir::isAbsolutePath(path))
+        return QString::fromLatin1("app/native/%1").arg(path);
+#elif !defined(Q_OS_ANDROID)
+    QString pathInInstallDir =
+            QString::fromLatin1("%1/../%2").arg(QCoreApplication::applicationDirPath(), path);
+    if (QFileInfo(pathInInstallDir).exists())
+        return pathInInstallDir;
+    pathInInstallDir =
+            QString::fromLatin1("%1/%2").arg(QCoreApplication::applicationDirPath(), path);
+    if (QFileInfo(pathInInstallDir).exists())
+        return pathInInstallDir;
+#endif
+    return path;
+}
+
+QtQuick2ApplicationViewer::QtQuick2ApplicationViewer(QWindow *parent)
+    : QQuickView(parent)
+    , d(new QtQuick2ApplicationViewerPrivate())
+{
+    connect(engine(), SIGNAL(quit()), SLOT(close()));
+    setResizeMode(QQuickView::SizeRootObjectToView);
+}
+
+QtQuick2ApplicationViewer::~QtQuick2ApplicationViewer()
+{
+    delete d;
+}
+
+void QtQuick2ApplicationViewer::setMainQmlFile(const QString &file)
+{
+    d->mainQmlFile = QtQuick2ApplicationViewerPrivate::adjustPath(file);
+#ifdef Q_OS_ANDROID
+    setSource(QUrl(QLatin1String("assets:/")+d->mainQmlFile));
+#else
+    setSource(QUrl::fromLocalFile(d->mainQmlFile));
+#endif
+}
+
+void QtQuick2ApplicationViewer::addImportPath(const QString &path)
+{
+    engine()->addImportPath(QtQuick2ApplicationViewerPrivate::adjustPath(path));
+}
+
+void QtQuick2ApplicationViewer::showExpanded()
+{
+#if defined(Q_WS_SIMULATOR) || defined(Q_OS_QNX)
+    showFullScreen();
+#else
+    show();
+#endif
+}

=== added file 'pay-test-app/qtquick2applicationviewer.h'
--- pay-test-app/qtquick2applicationviewer.h	1970-01-01 00:00:00 +0000
+++ pay-test-app/qtquick2applicationviewer.h	2014-08-05 23:30:20 +0000
@@ -0,0 +1,33 @@
+// checksum 0xfde6 version 0x90005
+/*
+  This file was generated by the Qt Quick 2 Application wizard of Qt Creator.
+  QtQuick2ApplicationViewer is a convenience class containing mobile device specific
+  code such as screen orientation handling. Also QML paths and debugging are
+  handled here.
+  It is recommended not to modify this file, since newer versions of Qt Creator
+  may offer an updated version of it.
+*/
+
+#ifndef QTQUICK2APPLICATIONVIEWER_H
+#define QTQUICK2APPLICATIONVIEWER_H
+
+#include <QtQuick/QQuickView>
+
+class QtQuick2ApplicationViewer : public QQuickView
+{
+    Q_OBJECT
+
+public:
+    explicit QtQuick2ApplicationViewer(QWindow *parent = 0);
+    virtual ~QtQuick2ApplicationViewer();
+
+    void setMainQmlFile(const QString &file);
+    void addImportPath(const QString &path);
+
+    void showExpanded();
+
+private:
+    class QtQuick2ApplicationViewerPrivate *d;
+};
+
+#endif // QTQUICK2APPLICATIONVIEWER_H

